# django-rtk-green

This package is the combination of the following django-rtk packages:

- django-rtk-later
- django-rtk-password
- django-rtk-magic-link

It has a Backend class that inherits from all the Backends in these packages.
Similarly, it has a Validator that inherits from all the Validators in these packages.
